@@ -4,6 +4,7 @@
 ## last changed 2009 03 30, 2009 06 11, 2009 07 08 2009 11 17
 ## revised 2010 04 01 with new argument append and character value allowed for header
 ## bug fixed 2010-06-07: use row names when single/multi
+## 2011-09-09 trivial: ms()
 ## Write capture histories to text file in DENSITY format
 ############################################################################################
 
@@ -14,7 +15,7 @@ write.captures <- function (object, file='', deblank = TRUE, header = TRUE,
     if (!is(object, 'capthist'))
         stop ("requires a 'capthist' object")
 
-    if (inherits(object, 'list')) {
+    if (ms(object)) {
         write.captures (object[[1]], file = file, deblank = deblank,
             header = deparse(substitute(object), control=NULL), append = append,
             sess = session(object)[1], ndec = ndec, covariates = covariates, ...)
